class mx.controls.streamingmedia.RTMPPlayer extends mx.controls.streamingmedia.AbstractPlayer implements mx.controls.streamingmedia.IPlayer
{
   var _mediaUrl;
   var _mediaType;
   var _videoHolder;
   var _video;
   var _totalTime;
   var _listeners;
   var _protocol;
   var _appInstName;
   var _streamName;
   var _isLoaded;
   var _sound;
   var _ns;
   var _nc;
   var _momentaryPlayId;
   var _statusCount;
   var _checkCompleteId;
   function RTMPPlayer(aMediaUrl, aMediaType, aVideoHolder, aTotalTime)
   {
      super();
      if(aMediaUrl == null || aVideoHolder == null || aTotalTime == null)
      {
         throw new Error("A media url, video object, and total time must be passed to RTMPPlayer\'s constructor");
      }
      this._mediaUrl = aMediaUrl;
      this._mediaType = aMediaType;
      this._videoHolder = aVideoHolder;
      this._video = this._videoHolder._video;
      this._totalTime = aTotalTime;
      this._listeners = new Array();
      this.init();
   }
   function init()
   {
      var _loc2_ = undefined;
      _loc2_ = this._mediaUrl.indexOf(":");
      if(_loc2_ == -1)
      {
         throw new Error("Invalid url, no protocol is specified");
      }
      this._protocol = this._mediaUrl.substring(0,_loc2_).toLowerCase();
      if(this._protocol != "rtmp" && this._protocol != "rtmps" && this._protocol != "rtmpt")
      {
         throw new Error("Invalid url, protocol is not supported");
      }
      _loc2_ = this._mediaUrl.lastIndexOf("/");
      this._appInstName = this._mediaUrl.substring(0,_loc2_);
      this._streamName = this._mediaUrl.substring(_loc2_ + 1,this._mediaUrl.length);
      if(this._streamName.length == 0)
      {
         throw new Error("Invalid url, no stream name is specified");
      }
      if(this._mediaType == mx.controls.streamingmedia.StreamingMediaConstants.FLV_MEDIA_TYPE)
      {
         _loc2_ = this._streamName.indexOf(".");
         if(_loc2_ != -1)
         {
            var _loc3_ = undefined;
            _loc3_ = this._streamName.substring(_loc2_).toLowerCase();
            if(_loc3_ == ".flv")
            {
               this._streamName = this._streamName.substring(0,_loc2_);
            }
         }
         this._streamName = "flv:" + this._streamName;
      }
      else
      {
         if(this._mediaType != mx.controls.streamingmedia.StreamingMediaConstants.MP3_MEDIA_TYPE)
         {
            throw new Error("The display must be playing mp3 or flv media. Instead it is trying to play " + this._mediaType);
         }
         _loc2_ = this._streamName.indexOf(".");
         if(_loc2_ != -1)
         {
            _loc3_ = this._streamName.substring(_loc2_).toLowerCase();
            if(_loc3_ == ".mp3")
            {
               this._streamName = this._streamName.substring(0,_loc2_);
            }
         }
         this._streamName = "mp3:" + this._streamName;
      }
      this.setPlaying(false);
      this._isLoaded = false;
      this._sound = new Sound(this._videoHolder);
      this.setVolume(mx.controls.streamingmedia.StreamingMediaConstants.DEFAULT_VOLUME);
   }
   function addListener(aListener)
   {
      this._listeners.push(aListener);
   }
   function removeAllListeners()
   {
      this._listeners.length = 0;
   }
   function broadcastEvent(status)
   {
      var _loc2_ = 0;
      while(_loc2_ < this._listeners.length)
      {
         this._listeners[_loc2_].handlePlayer(this,status);
         _loc2_ = _loc2_ + 1;
      }
   }
   function bufferIsFull()
   {
      this.broadcastEvent("start");
      if(!this.isPlaying())
      {
         this.pause();
      }
   }
   function toString()
   {
      return "RTMPPlayer: Playing " + this.getMediaUrl();
   }
   function close()
   {
      this._ns.close();
      this._nc.close();
      this._video.clear();
   }
   function load()
   {
      this._nc = new NetConnection();
      this._nc.connect(this._appInstName);
      this._ns = new mx.controls.streamingmedia.PlayerNetStream(this._nc,this);
      if(this._mediaType == mx.controls.streamingmedia.StreamingMediaConstants.FLV_MEDIA_TYPE)
      {
         this._video.attachVideo(this._ns);
      }
      this._video.attachVideo(this._ns);
      this._ns.setBufferTime(5);
      this._videoHolder.attachAudio(this._ns);
      this._ns.play(this._streamName,0,-1);
      this._isLoaded = true;
      this._videoHolder._visible = false;
      this.setPlaying(false);
   }
   function play(startingPoint)
   {
      if(!this._isLoaded)
      {
         this.load();
      }
      this._ns.pause(false);
      if(startingPoint != null)
      {
         this._ns.seek(startingPoint);
      }
      this.setPlaying(true);
   }
   function pause()
   {
      this._ns.pause(true);
      this.setPlaying(false);
   }
   function stop()
   {
      this.pause();
      this.setPlayheadTime(0);
   }
   function getPlayheadTime()
   {
      return this._ns.time;
   }
   function setPlayheadTime(position)
   {
      this._ns.seek(position);
      if(!mx.controls.streamingmedia.StreamingMediaConstants.SCRUBBING)
      {
         if(!this.isPlaying())
         {
            this._ns.pause(false);
            this._momentaryPlayId = setInterval(this,"doneUpdateFrame",50);
         }
      }
   }
   function doneUpdateFrame()
   {
      clearInterval(this._momentaryPlayId);
      this._momentaryPlayId = null;
      this._ns.pause(true);
   }
   function playStopped()
   {
      this._statusCount = 2;
      this._checkCompleteId = setInterval(this,"checkComplete",50);
   }
   function checkComplete()
   {
      if(this._ns.bufferLength <= 0.001)
      {
         if(this._statusCount <= 0)
         {
            clearInterval(this._checkCompleteId);
            this._checkCompleteId = null;
            this.pause();
            this.broadcastEvent("complete");
         }
         else
         {
            this._statusCount -= 1;
         }
      }
   }
   function getMediaUrl()
   {
      return this._mediaUrl;
   }
   function setMediaUrl(aUrl)
   {
      this._mediaUrl = aUrl;
      this._isLoaded = false;
      this.init();
      if(this.isPlaying())
      {
         this.play(0);
      }
      else
      {
         this.load();
      }
   }
   function getVolume()
   {
      return this._sound.getVolume();
   }
   function setVolume(aVol)
   {
      this._sound.setVolume(aVol);
   }
   function getMediaBytesLoaded()
   {
      return this._ns.bytesLoaded;
   }
   function getMediaBytesTotal()
   {
      return this._ns.bytesTotal;
   }
   function getTotalTime()
   {
      return this._totalTime;
   }
   function setTotalTime(aTime)
   {
      this._totalTime = aTime;
   }
   function mediaLoaded()
   {
   }
   function logError(error)
   {
      throw new Error(error);
   }
   function isSizeSet()
   {
      if(this._video.width > 0 && this._video.height > 0)
      {
         return true;
      }
      return false;
   }
}
